|
From: <cn...@us...> - 2025-05-22 19:32:35
|
Revision: 1588
http://sourceforge.net/p/seq/svn/1588
Author: cn187
Date: 2025-05-22 19:32:33 +0000 (Thu, 22 May 2025)
Log Message:
-----------
Historical checkin for 05/21/25
- Struct and opcode updates (Newby)
Version to 6.4.11
Modified Paths:
--------------
showeq/branches/cn187_devel/ChangeLog
showeq/branches/cn187_devel/conf/zoneopcodes.xml
showeq/branches/cn187_devel/configure.in
showeq/branches/cn187_devel/src/everquest.h
showeq/branches/cn187_devel/src/spawnshell.cpp
Modified: showeq/branches/cn187_devel/ChangeLog
===================================================================
--- showeq/branches/cn187_devel/ChangeLog 2025-05-22 01:10:26 UTC (rev 1587)
+++ showeq/branches/cn187_devel/ChangeLog 2025-05-22 19:32:33 UTC (rev 1588)
@@ -1,3 +1,9 @@
+BlueAdept (5/21/25)
+----------------
+- Update to version 6.4.11
+- Support for EQ Patch 5/21/25
+- Struct and opcode updates (Newby)
+
cn187 (4/16/25)
----------------
- Update to version 6.4.10
Modified: showeq/branches/cn187_devel/conf/zoneopcodes.xml
===================================================================
--- showeq/branches/cn187_devel/conf/zoneopcodes.xml 2025-05-22 01:10:26 UTC (rev 1587)
+++ showeq/branches/cn187_devel/conf/zoneopcodes.xml 2025-05-22 19:32:33 UTC (rev 1588)
@@ -3,37 +3,37 @@
<seqopcodes>
<!-- Critical opcodes used directly by ShowEQ -->
- <opcode id="25fd" name="OP_PlayerProfile" updated="04/16/25">
+ <opcode id="4f7f" name="OP_PlayerProfile" updated="05/21/25">
<comment>CharProfileCode</comment>
<payload dir="server" typename="uint8_t" sizechecktype="none"/>
</opcode>
- <opcode id="10bc" name="OP_ZoneEntry" updated="04/16/25">
+ <opcode id="77c9" name="OP_ZoneEntry" updated="05/21/25">
<comment>ZoneEntryCode</comment>
<payload dir="client" typename="ClientZoneEntryStruct" sizechecktype="match"/>
<payload dir="server" typename="uint8_t" sizechecktype="none"/>
</opcode>
- <opcode id="747f" name="OP_TimeOfDay" updated="04/16/25">
+ <opcode id="3488" name="OP_TimeOfDay" updated="05/21/25">
<comment>TimeOfDayCode</comment>
<payload dir="server" typename="timeOfDayStruct" sizechecktype="match"/>
</opcode>
- <opcode id="45e5" name="OP_NewZone" updated="04/16/25">
+ <opcode id="24ed" name="OP_NewZone" updated="05/21/25">
<comment>NewZoneCode</comment>
<payload dir="server" typename="uint8_t" sizechecktype="none"/>
</opcode>
- <opcode id="7b3b" name="OP_SpawnDoor" updated="04/16/25">
+ <opcode id="10ca" name="OP_SpawnDoor" updated="05/21/25">
<comment>DoorSpawnsCode</comment>
<payload dir="server" typename="doorStruct" sizechecktype="modulus"/>
</opcode>
- <opcode id="0aa0" name="OP_GroundSpawn" updated="04/16/25">
+ <opcode id="6d5a" name="OP_GroundSpawn" updated="05/21/25">
<comment>MakeDropCode</comment>
<payload dir="server" typename="makeDropStruct" sizechecktype="none"/>
<payload dir="client" typename="uint8_t" sizechecktype="none"/>
</opcode>
- <opcode id="3a81" name="OP_SendZonePoints" updated="04/16/25">
+ <opcode id="46f9" name="OP_SendZonePoints" updated="05/21/25">
<comment>Coords in a zone that will port you to another zone</comment>
<payload dir="server" typename="zonePointsStruct" sizechecktype="none"/>
</opcode>
- <opcode id="0101" name="OP_AAExpUpdate" updated="04/16/25">
+ <opcode id="22cc" name="OP_AAExpUpdate" updated="05/21/25">
<comment>Receiving AA experience. Also when percent to AA changes.</comment>
<payload dir="server" typename="altExpUpdateStruct" sizechecktype="match"/>
</opcode>
@@ -41,32 +41,32 @@
<comment>ExpUpdateCode</comment>
<payload dir="server" typename="expUpdateStruct" sizechecktype="match"/>
</opcode>
- <opcode id="2da1" name="OP_GuildMOTD" updated="04/16/25">
+ <opcode id="0f2f" name="OP_GuildMOTD" updated="05/21/25">
<comment>GuildMOTD</comment>
<payload dir="server" typename="guildMOTDStruct" sizechecktype="none"/>
</opcode>
- <opcode id="6721" name="OP_ClientUpdate" updated="04/16/25">
+ <opcode id="628c" name="OP_ClientUpdate" updated="05/21/25">
<comment>Position updates</comment>
<payload dir="server" typename="playerSpawnPosStruct" sizechecktype="match"/>
<payload dir="both" typename="playerSelfPosStruct" sizechecktype="match"/>
</opcode>
- <opcode id="42fc" name="OP_NpcMoveUpdate" updated="04/16/25">
+ <opcode id="3c85" name="OP_NpcMoveUpdate" updated="05/21/25">
<comment>Position updates</comment>
<payload dir="server" typename="uint8_t" sizechecktype="none"/>
</opcode>
- <opcode id="0f90" name="OP_MobUpdate" updated="04/16/25">
+ <opcode id="6844" name="OP_MobUpdate" updated="05/21/25">
<comment>MobUpdateCode</comment>
<payload dir="both" typename="spawnPositionUpdate" sizechecktype="match"/>
</opcode>
- <opcode id="1966" name="OP_DeleteSpawn" updated="04/16/25">
+ <opcode id="5bca" name="OP_DeleteSpawn" updated="05/21/25">
<comment>DeleteSpawnCode</comment>
<payload dir="both" typename="deleteSpawnStruct" sizechecktype="match"/>
</opcode>
- <opcode id="1a12" name="OP_RemoveSpawn" updated="04/16/25">
+ <opcode id="5e5e" name="OP_RemoveSpawn" updated="05/21/25">
<comment>Remove spawn from zone</comment>
<payload dir="both" typename="removeSpawnStruct" sizechecktype="none"/>
</opcode>
- <opcode id="5a1d" name="OP_Death" updated="04/16/25">
+ <opcode id="4a0d" name="OP_Death" updated="05/21/25">
<comment>old NewCorpseCode</comment>
<payload dir="server" typename="newCorpseStruct" sizechecktype="match"/>
</opcode>
@@ -74,7 +74,7 @@
<comment>SpawnUpdateCode</comment>
<payload dir="both" typename="SpawnUpdateStruct" sizechecktype="match"/>
</opcode>
- <opcode id="5828" name="OP_SpawnAppearance" updated="04/16/25">
+ <opcode id="1cbc" name="OP_SpawnAppearance" updated="05/21/25">
<comment>SpawnAppearanceCode</comment>
<payload dir="both" typename="spawnAppearanceStruct" sizechecktype="match"/>
</opcode>
@@ -86,15 +86,15 @@
<comment>NpcHpUpdateCode Update HP % of a PC or NPC</comment>
<payload dir="both" typename="hpNpcUpdateStruct" sizechecktype="match"/>
</opcode>
- <opcode id="44e9" name="OP_GuildMemberUpdate" updated="04/16/25">
+ <opcode id="0cae" name="OP_GuildMemberUpdate" updated="05/21/25">
<comment>Info regarding guild members</comment>
<payload dir="server" typename="GuildMemberUpdate" sizechecktype="match"/>
</opcode>
- <opcode id="1707" name="OP_ClickObject" updated="04/16/25">
+ <opcode id="4b61" name="OP_ClickObject" updated="05/21/25">
<comment>Items dropped on the ground</comment>
<payload dir="both" typename="remDropStruct" sizechecktype="match"/>
</opcode>
- <opcode id="7f06" name="OP_Action" updated="04/16/25">
+ <opcode id="280b" name="OP_Action" updated="05/21/25">
<comment>Spells cast etc</comment>
<payload dir="both" typename="actionStruct" sizechecktype="match"/>
<payload dir="both" typename="actionAltStruct" sizechecktype="match"/>
@@ -103,11 +103,11 @@
<comment>Combat actions i.e. bash, kick etc</comment>
<payload dir="both" typename="action2Struct" sizechecktype="match"/>
</opcode>
- <opcode id="5e7c" name="OP_Consider" updated="04/16/25">
+ <opcode id="57e0" name="OP_Consider" updated="05/21/25">
<comment>ConsiderCode</comment>
<payload dir="both" typename="considerStruct" sizechecktype="match"/>
</opcode>
- <opcode id="5022" name="OP_TargetMouse" updated="04/16/25">
+ <opcode id="0711" name="OP_TargetMouse" updated="05/21/25">
<comment>Targeting a person - old ClientTargetCode</comment>
<payload dir="both" typename="clientTargetStruct" sizechecktype="match"/>
</opcode>
@@ -123,7 +123,7 @@
<comment>Server putting players into shroud form</comment>
<payload dir="server" typename="spawnShroudSelf" sizechecktype="none"/>
</opcode>
- <opcode id="22f4" name="OP_ZoneChange" updated="04/16/25">
+ <opcode id="740a" name="OP_ZoneChange" updated="05/21/25">
<comment>old ZoneChangeCode</comment>
<payload dir="both" typename="zoneChangeStruct" sizechecktype="match"/>
</opcode>
@@ -191,19 +191,19 @@
<comment>EmoteTextCode</comment>
<payload dir="both" typename="emoteTextStruct" sizechecktype="none"/>
</opcode>
- <opcode id="2e0e" name="OP_SimpleMessage" updated="04/16/25">
+ <opcode id="5503" name="OP_SimpleMessage" updated="05/21/25">
<comment>SimpleMessageCode</comment>
<payload dir="server" typename="simpleMessageStruct" sizechecktype="match"/>
</opcode>
- <opcode id="64c6" name="OP_FormattedMessage" updated="04/16/25">
+ <opcode id="17c0" name="OP_FormattedMessage" updated="05/21/25">
<comment>FormattedMessageCode i.e. pet dismissed etc</comment>
<payload dir="server" typename="formattedMessageStruct" sizechecktype="none"/>
</opcode>
- <opcode id="5549" name="OP_CommonMessage" updated="04/16/25">
+ <opcode id="4161" name="OP_CommonMessage" updated="05/21/25">
<comment>ChannelMessageCode i.e. /tell /ooc /shout etc</comment>
<payload dir="both" typename="channelMessageStruct" sizechecktype="none"/>
</opcode>
- <opcode id="1284" name="OP_SpecialMesg" updated="04/16/25">
+ <opcode id="7706" name="OP_SpecialMesg" updated="05/21/25">
<comment>Communicate textual info to client including hail responses etc</comment>
<payload dir="server" typename="specialMessageStruct" sizechecktype="none"/>
</opcode>
@@ -315,7 +315,7 @@
<comment>List of group members - Variable length</comment>
<payload dir="server" typename="uint8_t" sizechecktype="none"/>
</opcode>
- <opcode id="06b1" name="OP_GuildMemberList" updated="04/16/25">
+ <opcode id="2f4c" name="OP_GuildMemberList" updated="05/21/25">
<comment>List of guild members - Variable length</comment>
<payload dir="server" typename="uint8_t" sizechecktype="none"/>
</opcode>
@@ -375,7 +375,7 @@
<comment>Fellowship information - 2576 bytes</comment>
<payload dir="server" typename="uint8_t" sizechecktype="none"/>
</opcode>
- <opcode id="3b66" name="OP_ExpandedGuildInfo" updated="04/16/25">
+ <opcode id="36e0" name="OP_ExpandedGuildInfo" updated="05/21/25">
<comment>Guild ranks and other misc guild data - Variable length</comment>
<payload dir="server" typename="uint8_t" sizechecktype="none"/>
</opcode>
@@ -543,7 +543,7 @@
<comment>Listing of all guilds. Can be triggered by /lfg search?</comment>
<payload dir="server" typename="uint8_t" sizechecktype="none"/>
</opcode>
- <opcode id="7ba3" name="OP_GuildsInZoneList" updated="04/16/25">
+ <opcode id="6417" name="OP_GuildsInZoneList" updated="05/21/25">
<comment>Listing of guild names present in the current zone. Generally seen on zoning</comment>
<payload dir="server" typename="guildsInZoneListStruct" sizechecktype="none"/>
</opcode>
@@ -603,7 +603,7 @@
<comment>Free to play nags and other data - Variable length</comment>
<payload dir="server" typename="uint8_t" sizechecktype="none"/>
</opcode>
- <opcode id="26ed" name="OP_Find" updated="04/16/25">
+ <opcode id="4aff" name="OP_Find" updated="05/21/25">
<comment>Find window data - variable length, 24 min</comment>
<payload dir="server" typename="uint8_t" sizechecktype="none"/>
</opcode>
Modified: showeq/branches/cn187_devel/configure.in
===================================================================
--- showeq/branches/cn187_devel/configure.in 2025-05-22 01:10:26 UTC (rev 1587)
+++ showeq/branches/cn187_devel/configure.in 2025-05-22 19:32:33 UTC (rev 1588)
@@ -2,7 +2,7 @@
dnl $Id$ $Name$
AC_PREREQ(2.59)
-AC_INIT(showeq, 6.4.10)
+AC_INIT(showeq, 6.4.11)
AC_CONFIG_SRCDIR(src/main.cpp)
AC_CONFIG_MACRO_DIR([m4])
AC_CANONICAL_SYSTEM
Modified: showeq/branches/cn187_devel/src/everquest.h
===================================================================
--- showeq/branches/cn187_devel/src/everquest.h 2025-05-22 01:10:26 UTC (rev 1587)
+++ showeq/branches/cn187_devel/src/everquest.h 2025-05-22 19:32:33 UTC (rev 1588)
@@ -1119,26 +1119,29 @@
struct
{
+ signed y:19; // y coord (2nd loc value)
+ signed deltaZ:13; // change in z
+
signed deltaHeading:10; // change in heading
- signed x:19; // x coord (1st loc value)
- unsigned padding00:3;
-
signed deltaX:13; // change in x
- signed y:19; // y coord (2nd loc value)
+ unsigned padding01:9;
- signed z:19; // z coord (3rd loc value)
- signed deltaY:13; // change in y
-
- signed deltaZ:13; // change in z
signed animation:10; // current animation
- unsigned padding03:9;
+ unsigned heading:12; // heading
+ unsigned padding02:10;
- unsigned heading:12; // heading
unsigned pitch:12; // pitch (up/down heading)
- unsigned padding04:8;
+ signed deltaY:13; // change in y
+ unsigned padding03:7;
+ signed x:19; // x coord (1st loc value)
+ unsigned padding04:13;
+
+ signed z:19; // z coord (3rd loc value)
+ unsigned padding05:13;
+
};
- int32_t posData[5];
+ int32_t posData[6];
};
/*0000*/ union
@@ -2388,7 +2391,7 @@
/*
** Player Position Update
-** Length: 24 Octets
+** Length: 28 Octets
** OpCode: PlayerPosCode
*/
struct playerSpawnPosStruct
@@ -2396,29 +2399,32 @@
/*0000*/ uint16_t spawnId;
/*0002*/ uint16_t spawnId2;
/*0004*/
+ signed y:19; // y coord (2nd loc value)
+ signed deltaZ:13; // change in z
+/*0008*/
signed deltaHeading:10; // change in heading
- signed x:19; // x coord (1st loc value)
- unsigned padding00:3;
-/*0008*/
signed deltaX:13; // change in x
- signed y:19; // y coord (2nd loc value)
+ unsigned padding01:9;
/*0012*/
- signed z:19; // z coord (3rd loc value)
- signed deltaY:13; // change in y
-/*0016*/
- signed deltaZ:13; // change in z
signed animation:10; // current animation
- unsigned padding03:9;
-/*0020*/
unsigned heading:12; // heading
+ unsigned padding02:10;
+/*0016*/
unsigned pitch:12; // pitch (up/down heading)
- unsigned padding04:8;
+ signed deltaY:13; // change in y
+ unsigned padding03:7;
+/*0020*/
+ signed x:19; // x coord (1st loc value)
+ unsigned padding04:13;
/*0024*/
+ signed z:19; // z coord (3rd loc value)
+ unsigned padding05:13;
+/*0028*/
};
/*
** Self Position Update
-** Length: 38 Octets
+** Length: 42 Octets
** OpCode: PlayerPosCode
*/
struct playerSelfPosStruct
@@ -2427,25 +2433,28 @@
/*0002*/ uint16_t spawnId; // Player's spawn id
/*0004*/ uint16_t unknown0004; // ***Placeholder
/*0006*/
- float deltaY; // change in y
+ float deltaX; // change in x
/*0010*/
- float deltaZ; // change in z
+ unsigned heading:12; // heading
+ unsigned padding01:20;
/*0014*/
+ float deltaY; // change in y
+/*0018*/
float x; // x coord (1st loc value)
-/*0018*/
- float deltaX; // change in x
/*0022*/
- signed animation:10; // current animation
- signed deltaHeading:10; // change in heading
- unsigned heading:12; // heading
+ float y; // y coord (2nd loc value)
/*0026*/
- float y; // y coord (2nd loc value)
+ float z; // z coord (3rd loc value)
/*0030*/
- float z; // z coord (3rd loc value)
+ unsigned pitch:12; // pitch (up/down heading)
+ signed deltaHeading:10; // change in heading
+ unsigned padding06:10;
/*0034*/
- unsigned pitch:12; // pitch (up/down heading)
- unsigned padding07:20;
+ float deltaZ; // change in z
/*0038*/
+ signed animation:10; // current animation
+ unsigned padding08:22;
+/*0042*/
};
/*
Modified: showeq/branches/cn187_devel/src/spawnshell.cpp
===================================================================
--- showeq/branches/cn187_devel/src/spawnshell.cpp 2025-05-22 01:10:26 UTC (rev 1587)
+++ showeq/branches/cn187_devel/src/spawnshell.cpp 2025-05-22 19:32:33 UTC (rev 1588)
@@ -649,8 +649,8 @@
spawn->spawnId = netStream.readUInt32NC();
spawn->level = netStream.readUInt8();
- // skip the next 12 bytes
- netStream.skipBytes(12);
+ // skip the next 16 bytes
+ netStream.skipBytes(16);
spawn->NPC = netStream.readUInt8();
spawn->miscData = netStream.readUInt32NC();
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|